Module ipfix

Module ipfix 

Structs

Data
FieldParser
FlowSet
FlowSetHeader
Header
IPFix
IPFixParser
NoTemplateInfo
Information about a data flowset that couldn’t be parsed due to missing template.
OptionsData
OptionsTemplate
Template
TemplateField

Enums

FlowSetBody

Constants

DEFAULT_MAX_TEMPLATE_CACHE_SIZE
Default maximum number of templates to cache per parser
MAX_FIELD_COUNT
Default maximum number of fields allowed per template to prevent DoS attacks A reasonable limit that should accommodate legitimate use cases This can be configured per-parser via the Config struct

Type Aliases

IPFixFieldPair
IpFixFlowRecord