OptionsData

Struct OptionsData 

pub struct OptionsData {
    pub fields: Vec<Vec<IPFixFieldPair>>,
    pub padding: Vec<u8>,
}

Fields

fields: Vec<Vec<IPFixFieldPair>>padding: Vec<u8>

Implementations

Source

impl<'nom> OptionsData

pub fn parse_be( orig_i: &'nom [u8], template: &OptionsTemplate, ) -> IResult<&'nom [u8], Self>

pub fn parse_le( orig_i: &'nom [u8], template: &OptionsTemplate, ) -> IResult<&'nom [u8], Self>

pub fn parse( orig_i: &'nom [u8], template: &OptionsTemplate, ) -> IResult<&'nom [u8], Self>

Source

impl OptionsData

pub fn new(fields: Vec<Vec<IPFixFieldPair>>) -> Self

Creates a new OptionsData instance with the given fields. The padding field is automatically set to an empty vector and will be calculated during export for manually created packets.