#[non_exhaustive]pub enum ConfigError {
Show 16 variants
InvalidCacheSize(usize),
InvalidPendingCacheSize(usize),
InvalidAllowedVersion(u16),
InvalidFieldCount(usize),
InvalidTemplateTotalSize(usize),
InvalidEntriesPerTemplate(usize),
InvalidEntrySize(usize),
InvalidTtlDuration,
EmptyAllowedVersions,
InvalidRecordsPerFlowset(usize),
InvalidDecodedFieldValueLimit(usize),
InvalidDecodedFieldPayloadByteLimit(usize),
InvalidV9FrameSize(usize),
InvalidPendingTotalBytes {
max_total_bytes: usize,
max_entry_size_bytes: usize,
},
InvalidMaxSources(usize),
InvalidErrorSampleSize(usize),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidCacheSize(usize)
Template cache size must be greater than 0
InvalidPendingCacheSize(usize)
Pending flow cache size must be greater than 0
InvalidAllowedVersion(u16)
An allowed version number is out of the supported range (0-10)
InvalidFieldCount(usize)
Max field count must be greater than 0
InvalidTemplateTotalSize(usize)
Max template total size must be greater than 0
InvalidEntriesPerTemplate(usize)
Pending flow max entries per template must be greater than 0
InvalidEntrySize(usize)
Pending flow max entry size must be between 1 and 65531 (u16::MAX - 4)
InvalidTtlDuration
TTL duration must be greater than zero
EmptyAllowedVersions
Allowed versions list must not be empty
InvalidRecordsPerFlowset(usize)
Max records per flowset must be greater than 0
InvalidDecodedFieldValueLimit(usize)
Decoded field-value message limit must be greater than 0.
InvalidDecodedFieldPayloadByteLimit(usize)
Decoded field-payload-byte message limit must be greater than 0.
InvalidV9FrameSize(usize)
NetFlow v9 frame size must be greater than 0
InvalidPendingTotalBytes
Pending flow max_total_bytes must be >= max_entry_size_bytes
InvalidMaxSources(usize)
max_sources must be greater than 0
InvalidErrorSampleSize(usize)
max_error_sample_size must be greater than 0