Structs
- Data
- Field
Parser - FlowSet
- Flow
SetHeader - Header
- IPFix
- IPFix
Parser - NoTemplate
Info - Information about a data flowset that couldn’t be parsed due to missing template.
- Options
Data - Options
Template - Template
- Template
Field
Enums
Constants
- DEFAULT_
MAX_ TEMPLATE_ CACHE_ SIZE - Default maximum number of templates to cache per parser
- MAX_
FIELD_ COUNT - Default maximum number of fields allowed per template to prevent DoS attacks A reasonable limit that should accommodate legitimate use cases This can be configured per-parser via the Config struct